#ifndef MPLAYERBACKENDADDON_H
#define MPLAYERBACKENDADDON_H

#include "addonmanager.h"

#include "playbackbackend.h"
#include "mplayerbackend.h"

#include "mediaidentifier.h"
#include "mplayermediaidentifier.h"

#include "configurationdialog.h"
#include "mplayerconfig.h"

class MPlayerBackendAddOn : public AddOn, public AbstractPlaybackBackendFactory
{
    Q_OBJECT
public:
    static MPlayerBackendAddOn& singleton();
#	define gMPlayerBackendAddOn MPlayerBackendAddOn::singleton()

    MPlayerBackendAddOn()
        :	AddOn(),
            identifier_(config_)
    {
        qDebug("Registering MPlayerBackendAddOn");
    }

    virtual ~MPlayerBackendAddOn() {}

    virtual void init()
    {
        globalPlaybackBackendRegistry.registerFactory(this);
        gMediaIdentifier.registerIdentifier(&identifier_);
    }

    virtual void hookMainWindow(Quasar *mainWindow)
    {
        mainWindow_ = mainWindow;
    }

    virtual void hookConfigurationDialog(ConfigurationDialog *cd)
    {
        cd_ = cd;

        MPlayerConfig *cv = new MPlayerConfig(cd->config(), cd);
        cd->initializeAndAddConfigViewTab(cv, cv, tr("MPlayer"));

        connect(cd_, SIGNAL(settingDefaultSettings()), cv, SLOT(setDefaultSettings()));
    }

    virtual void writeToConfig(Config &cf)
    {
        config_.write(cf);
    }

    virtual void readFromConfig(Config &cf)
    {
        config_.read(cf);
    }

    MPlayerConfiguration &config() { return config_; }

    /* AbstractPlaybackBackendFactory */

    virtual QString internalClassName() const { return QString("MPlayer"); }
    virtual QString friendlyDisplayName() const { return QString("MPlayer"); }

    virtual AbstractPlaybackBackend *createInstance();

    virtual bool supportsFormatSpecificConfigs() { return true; }
    virtual void setFormatSpecificConfigDefaults(Configuration &config) { config_.setFormatSpecificConfigDefaults(config); }
    virtual PlaybackBackendConfigWidget *createConfigWidget(QWidget *parent) { return new MPlayerFormatsConfig(parent); }

private:
    Quasar *mainWindow_;
    ConfigurationDialog *cd_;
    MPlayerConfiguration config_;

    MPlayerMediaIdentifier identifier_;
};

#endif // MPLAYERBACKENDADDON_H
